@@ -1,10 +1,10 @@
-is.pd <- function(x, check.asyCov=FALSE, cor.analysis=TRUE, tol=1e-06) {
+is.pd <- function(x, check.aCov=FALSE, cor.analysis=TRUE, tol=1e-06) {
     if (is.list(x)) {
-        return(sapply(x, is.pd, check.asyCov=check.asyCov, cor.analysis=cor.analysis, tol=tol))
+        return(sapply(x, is.pd, check.aCov=check.aCov, cor.analysis=cor.analysis, tol=tol))
     }
     else {
         ## Criteria based on asyCov()
-        if (check.asyCov) {
+        if (check.aCov) {
             if (cor.analysis) Diag(x)[is.na(Diag(x))] <- 1 else Diag(x)[is.na(Diag(x))] <- mean(Diag(x), na.rm=TRUE)
             x[is.na(x)] <- 0
         } else {
