@@ -12,12 +12,21 @@ list2matrix <- function(x, diag=FALSE) {
    
   if (diag) {
     psNames <- vech(outer(oldNames, oldNames, paste, sep = "_"))
-    out <- t(sapply(x, function(x) {(vech(x))}))
+    ## out <- t(sapply(x, function(x) {(vech(x))}))
+    ## out is a list
+    out <- lapply(x, vech)    
   } else {
     psNames <- vechs(outer(oldNames, oldNames, paste, sep = "_"))
-    out <- t(sapply(x, function(x) {(vechs(x))}))
+    ## Fix a bug found by Steffen Zitzmann when x is a 2x2 matrix with diag=FALSE
+    ## It returns 1xn vector rather than nx1 because of sapply().
+    ## out <- t(sapply(x, function(x) {(vechs(x))}))
+    out <- lapply(x, vechs)
   }
 
+  ## convert the list into a matrix
+  ## out <- matrix(unlist(out), nrow=length(out), byrow=TRUE)
+  out <- do.call(rbind, out)
+  
   dimnames(out) <- list(names(x), psNames)
   out
 }
